#ifndef NT2_INCLUDE_FUNCTIONS_COTD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_COTD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cotd.hpp>

#endif
